@@ -1,4 +1,4 @@
-ReadGem_v0.85= function(nums = 0:9999, path = './', alloutput = FALSE, verbose = TRUE, requireGPS = FALSE, SN = character()){
+ReadGem_v0.8= function(nums = 0:9999, path = './', alloutput = FALSE, verbose = TRUE, requireGPS = FALSE, SN = character()){
   preamble_length = 4
   
   ## find the relevant files
@@ -55,7 +55,7 @@ ReadGem_v0.85= function(nums = 0:9999, path = './', alloutput = FALSE, verbose =
     
     body = R[(preamble_length+2):length(R)]
     body = body[!is.na(iconv(body))] ## to prevent substr from choking on any multibyte characters (from bad lines)--JFA 2017-10-13
-    linetype = substr(body, 1, 1)
+    linetype = substr(iconv(body), 1, 1)
     wg = which(linetype == 'G')
     if(length(wg) == 0 && requireGPS){
       warning(paste('Skipping file (no GPS): ', fn[i]))
@@ -63,10 +63,6 @@ ReadGem_v0.85= function(nums = 0:9999, path = './', alloutput = FALSE, verbose =
     }
     wm = which(linetype == 'M')
     wd = which(linetype == 'D')
-
-    ## these linetypes aren't actually used here, but they're useful for debugging
-    wr = which(linetype == 'R')
-    wp = which(linetype == 'P')
     
     ## if we don't have any data, skip the file
     if(length(wd) == 0){
@@ -97,19 +93,18 @@ ReadGem_v0.85= function(nums = 0:9999, path = './', alloutput = FALSE, verbose =
     
     ## Make metadata matrix if data are available
     if(length(wm) > 0){ # only do this if there are metadata lines to draw from
-      L$m = Lines2Matrix(body[wm], 12)
+      L$m = Lines2Matrix(body[wm], 10)
       if(length(attr(L$m, 'na.values')) > 0){
         warning('Skipping ', length(attr(L$m, 'na.values')), ' corrupt metadata lines in file ', fn[i], ': could cause timing errors')
         wm = wm[-attr(L$m, 'na.values')]
       }
-      L$m = as.data.frame(L$m); names(L$m) = c('millis', 'batt', 'temp', 'A2', 'A3', 'maxWriteTime', 'minFifoFree', 'maxFifoUsed', 'maxOverruns', 'gpsOnFlag', 'unusedStack1', 'unusedStackIdle')
+      L$m = as.data.frame(L$m); names(L$m) = c('millis', 'batt', 'temp', 'maxWriteTime', 'minFifoFree', 'maxFifoUsed', 'maxOverruns', 'gpsOnFlag', 'unusedStack1', 'unusedStackIdle')
       L$m$t = rep(NA, length(L$m$millis))
       class(L$m$t) = c('POSIXct', 'POSIXt') # this is necessary to prevent problems with NA coercion to POSIXct, if timing isn't available.
     }
     
     if(!(requireGPS && length(wg)==0)){
       ## Make the millis vector
-                                        #            millis = 0*1:(length(wd)+length(wg)+length(wm))
       millis = 0*1:length(body)
       millis[wd] = L$d$millis
       if(length(wg) > 0){
@@ -212,7 +207,7 @@ ReadGem_v0.85= function(nums = 0:9999, path = './', alloutput = FALSE, verbose =
     
     ## append GPS data if present
     if(length(wg) > 1){
-      OUTPUT$gps = rbind(OUTPUT$gps, as.data.frame(cbind(year = L$g$yr, date = L$g$td, lat = L$g$lat, lon = L$g$lon))[!wna,])
+      OUTPUT$gps = rbind(OUTPUT$gps, as.data.frame(cbind(year = L$g$yr, date = L$g$td, lat = L$g$lat, lon = L$g$lon)))#[!wna,])# 2020-01-01: wna is redundant (has already been used to eliminate NaNs above, as wgood)
     }
     
     ## append header info: each item is a vector with each element corresponding to a file
